@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::POE;
-$Acme::CPANAuthors::POE::VERSION = '0.82';
+$Acme::CPANAuthors::POE::VERSION = '0.84';
 #ABSTRACT: We are CPAN Authors of POE
 
 use strict;
@@ -18,7 +18,7 @@ use Acme::CPANAuthors::Register (
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
-  AVENJ => q[Jon Portnoy],
+  AVENJ => q[Jon Portnoy (PAUSE Custodial Account)],
   BARBIE => q[Barbie],
   BEVO => q[Brendan Beveridge],
   BIGPRESH => q[David Precious],
@@ -31,9 +31,9 @@ use Acme::CPANAuthors::Register (
   CCOBB => q[Chris Cobb],
   CFEDDE => q[Chris Fedde],
   CLAESJAC => q[Claes Jakobsson],
-  COSIMO => q[Cosimo Streppone],
   CURTIS => q[Curtis Brandt],
   CWEST => q[Casey West],
+  DAEMON => q[Paul G Webster (Account no longer used)],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
   DAVINCHI => q[Pavel Boldin],
@@ -159,7 +159,7 @@ use Acme::CPANAuthors::Register (
   XANTUS => q[David Davis],
   XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
-  YBLUSSEAU => q[Yves Blusseau],
+  YBLUSSEAU => q[yblusseau],
   ZOFFIX => q[Zoffix Znet],
 );
 
@@ -177,7 +177,7 @@ Acme::CPANAuthors::POE - We are CPAN Authors of POE
 
 =head1 VERSION
 
-version 0.82
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -212,7 +212,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
-  AVENJ => q[Jon Portnoy],
+  AVENJ => q[Jon Portnoy (PAUSE Custodial Account)],
   BARBIE => q[Barbie],
   BEVO => q[Brendan Beveridge],
   BIGPRESH => q[David Precious],
@@ -225,9 +225,9 @@ It is currently statically generated information, I hope to make it dynamic in t
   CCOBB => q[Chris Cobb],
   CFEDDE => q[Chris Fedde],
   CLAESJAC => q[Claes Jakobsson],
-  COSIMO => q[Cosimo Streppone],
   CURTIS => q[Curtis Brandt],
   CWEST => q[Casey West],
+  DAEMON => q[Paul G Webster (Account no longer used)],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
   DAVINCHI => q[Pavel Boldin],
@@ -353,7 +353,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   XANTUS => q[David Davis],
   XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
-  YBLUSSEAU => q[Yves Blusseau],
+  YBLUSSEAU => q[yblusseau],
   ZOFFIX => q[Zoffix Znet],
 
 =head1 SEE ALSO
@@ -368,7 +368,7 @@ Chris Williams
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
